houdini-logging-tools
=====================

[![PyPI version](https://img.shields.io/pypi/v/houdini-logging-tools)](https://pypi.org/pypi/houdini-logging-tools)
[![Tests](https://github.com/captainhammy/houdini-logging-tools/actions/workflows/tests.yml/badge.svg)](https://github.com/captainhammy/houdini-logging-tools/actions/workflows/tests.yml)
[![Documentation Status](https://readthedocs.org/projects/houdini-logging-tools/badge/?version=latest)](https://houdini-logging-tools.readthedocs.io/en/latest/?badge=latest)
[![codecov](https://codecov.io/gh/captainhammy/houdini-logging-tools/graph/badge.svg?token=P25YCTBI8B)](https://codecov.io/gh/captainhammy/houdini-logging-tools)

This project contains utilities related to Python logging in [Houdini](http://sidefx.com).
